==> slumber-1.3.0.tar.gz: slumber-1.3.0/docs/src/SUMMARY.md <==
# Summary

- [Introduction](./introduction.md)
- [Install](./install.md)
- [Getting Started](./getting_started.md)

# User Guide

- [Key Concepts](./user_guide/key_concepts.md)
- [Terminal User Interface (TUI)](./user_guide/tui.md)
- [Command Line Interface (CLI)](./user_guide/cli.md)
- [Templates](./user_guide/templates.md)
- [Chains - Complex Recipe Values](./user_guide/chains.md)
- [Collection Reuse & Inheritance](./user_guide/inheritance.md)
- [Data Filtering & Querying](./user_guide/filter_query.md)
- [Importing External Collections](./user_guide/import.md)

# CLI Commands

- [slumber request](./cli/request.md)
- [slumber import](./cli/import.md)
- [slumber generate](./cli/generate.md)
- [slumber collections](./cli/collections.md)
- [slumber show](./cli/show.md)

# API Reference

- [Request Collection](./api/request_collection/index.md)
  - [Profile](./api/request_collection/profile.md)
  - [Request Recipe](./api/request_collection/request_recipe.md)
  - [Authentication](./api/request_collection/authentication.md)
  - [Chain](./api/request_collection/chain.md)
  - [Chain Source](./api/request_collection/chain_source.md)
  - [Template](./api/request_collection/template.md)
  - [Content Type](./api/request_collection/content_type.md)
- [Configuration](./api/configuration/index.md)
  - [Input Bindings](./api/configuration/input_bindings.md)
  - [Theme](./api/configuration/theme.md)

# Troubleshooting

- [Lost Request History](./troubleshooting/lost_history.md)
- [TLS Certificate Errors](./troubleshooting/tls.md)

==> slumber-1.3.2.tar.gz: slumber-1.3.2/docs/src/SUMMARY.md <==
# Summary

- [Introduction](./introduction.md)
- [Install](./install.md)
- [Getting Started](./getting_started.md)

# User Guide

- [Key Concepts](./user_guide/key_concepts.md)
- [Terminal User Interface (TUI)](./user_guide/tui.md)
- [Command Line Interface (CLI)](./user_guide/cli.md)
- [Templates](./user_guide/templates.md)
  - [Chains - Complex Template Values](./user_guide/chains.md)
- [Collection Reuse & Inheritance](./user_guide/inheritance.md)
- [Data Filtering & Querying](./user_guide/filter_query.md)
- [Importing External Collections](./user_guide/import.md)

# CLI Commands

- [slumber request](./cli/request.md)
- [slumber import](./cli/import.md)
- [slumber generate](./cli/generate.md)
- [slumber collections](./cli/collections.md)
- [slumber show](./cli/show.md)

# API Reference

- [Request Collection](./api/request_collection/index.md)
  - [Profile](./api/request_collection/profile.md)
  - [Request Recipe](./api/request_collection/request_recipe.md)
  - [Authentication](./api/request_collection/authentication.md)
  - [Chain](./api/request_collection/chain.md)
  - [Chain Source](./api/request_collection/chain_source.md)
  - [Template](./api/request_collection/template.md)
  - [Content Type](./api/request_collection/content_type.md)
- [Configuration](./api/configuration/index.md)
  - [Input Bindings](./api/configuration/input_bindings.md)
  - [Theme](./api/configuration/theme.md)

# Troubleshooting

- [Lost Request History](./troubleshooting/lost_history.md)
- [TLS Certificate Errors](./troubleshooting/tls.md)
